using System;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.Data.SqlClient;

public class CustomGridStyles : System.Windows.Forms.Form
{
	private Button btnShowOrders;
	private DataGrid myDataGrid;   
	private DataSet myDataSet;
	private Button btnShowCustomers;
	private bool TablesAlreadyAdded;

	public CustomGridStyles()
	{
		InitializeComponent();

		// Get Customers and Orders from the Database
        MakeDataSet();

		// Show the Customers Table withot custom Table Style
		myDataGrid.DataSource = myDataSet.Tables["Customers"];
	}

	private void InitializeComponent()
	{
		this.btnShowOrders = new System.Windows.Forms.Button();
		this.myDataGrid = new System.Windows.Forms.DataGrid();
		this.btnShowCustomers = new System.Windows.Forms.Button();
		((System.ComponentModel.ISupportInitialize)(this.myDataGrid)).BeginInit();
		this.SuspendLayout();
		// 
		// btnShowOrders
		// 
		this.btnShowOrders.Location = new System.Drawing.Point(8, 8);
		this.btnShowOrders.Name = "btnShowOrders";
		this.btnShowOrders.Size = new System.Drawing.Size(120, 24);
		this.btnShowOrders.TabIndex = 0;
		this.btnShowOrders.Text = "Show Orders";
		this.btnShowOrders.Click += new System.EventHandler(this.btnShowOrders_Click);
		// 
		// myDataGrid
		// 
		this.myDataGrid.CaptionText = "Unformated Customer Table";
		this.myDataGrid.DataMember = "";
		this.myDataGrid.HeaderForeColor = System.Drawing.SystemColors.ControlText;
		this.myDataGrid.Location = new System.Drawing.Point(8, 40);
		this.myDataGrid.Name = "myDataGrid";
		this.myDataGrid.Size = new System.Drawing.Size(300, 200);
		this.myDataGrid.TabIndex = 2;
		this.myDataGrid.MouseUp += new System.Windows.Forms.MouseEventHandler(this.Grid_MouseUp);
		// 
		// btnShowCustomers
		// 
		this.btnShowCustomers.Location = new System.Drawing.Point(188, 8);
		this.btnShowCustomers.Name = "btnShowCustomers";
		this.btnShowCustomers.Size = new System.Drawing.Size(120, 24);
		this.btnShowCustomers.TabIndex = 3;
		this.btnShowCustomers.Text = "Show Customers";
		this.btnShowCustomers.Click += new System.EventHandler(this.btnShowCustomers_Click);
		// 
		// CustomGridStyles
		// 
		this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
		this.ClientSize = new System.Drawing.Size(320, 245);
		this.Controls.Add(this.btnShowCustomers);
		this.Controls.Add(this.btnShowOrders);
		this.Controls.Add(this.myDataGrid);
		this.Name = "CustomGridStyles";
		this.Text = "DataGrid Control Sample";
		((System.ComponentModel.ISupportInitialize)(this.myDataGrid)).EndInit();
		this.ResumeLayout(false);

	}

	public static void Main()
	{
		Application.Run(new CustomGridStyles());
	}

	// Show Orders Table with custom Table/Column Style
	protected void btnShowOrders_Click(object sender, System.EventArgs e)
	{
		if (!TablesAlreadyAdded) 
		{
			AddCustomDataTableStyle();
		}
		myDataGrid.SetDataBinding(myDataSet, "Orders");
		myDataGrid.CaptionText = "Formatted Orders Table";
	}

	// Show Customers Table with custom Table/Column Style
	private void btnShowCustomers_Click(object sender, System.EventArgs e)
	{
		if (!TablesAlreadyAdded) 
		{
			AddCustomDataTableStyle();
		}
		myDataGrid.SetDataBinding(myDataSet, "Customers");
		myDataGrid.CaptionText = "Formatted Customers Table";
	}

	// Create own Table/Column Styles
	private void AddCustomDataTableStyle()
	{
		// Create the first DataGridTableStyle which is used
		// for the "Customers" Table
		DataGridTableStyle ts1 = new DataGridTableStyle();
		ts1.MappingName = "Customers";

		// Set other properties.
		ts1.AlternatingBackColor = Color.LightBlue;

		// Create a first column style and set its MappingName 
		// to the "CustomerID" column of the "Customers" Table.
		// Set the HeaderText and Width properties. Well I know
		// for the "CustomerID" Column it makes not much sense to
		// set a DataGridBoolColumn ... it's just a Demo.
		DataGridColumnStyle boolCol = new DataGridBoolColumn();
		boolCol.MappingName = "CustomerID";
		boolCol.HeaderText = "ID";
		boolCol.Width = 50;
		ts1.GridColumnStyles.Add(boolCol);
      
		// Add a second column style and set its MappingName 
		// to the "CompanyName" column of the "Customers" Table.
		DataGridColumnStyle TextCol = new DataGridTextBoxColumn();
		TextCol.MappingName = "CompanyName";
		TextCol.HeaderText = "Company";
		TextCol.Width = 250;
		ts1.GridColumnStyles.Add(TextCol);

		// Create the second DataGridTableStyle which is used
		// for the "Orders" Table.
		DataGridTableStyle ts2 = new DataGridTableStyle();
		ts2.MappingName = "Orders";

		// Set other properties.
		ts2.AlternatingBackColor = Color.LightGray;
      
		// Use a PropertyDescriptor to create a formatted
		// column. First get the PropertyDescriptorCollection
		// for the data source and data member
		PropertyDescriptorCollection pcol = this.BindingContext
			[myDataSet,"Orders"].GetItemProperties();

		// Create a first formatted column style and set its MappingName 
		// to the OrderDate" column of the "Orders" Table.
		// Format the DateTime as Long Format "F"
		DataGridColumnStyle cOrderDate =
            new DataGridTextBoxColumn(pcol["OrderDate"], "F", true);
		cOrderDate.MappingName = "OrderDate";
		cOrderDate.HeaderText = "Formatted Order Date";
		cOrderDate.Width = 200;
		ts2.GridColumnStyles.Add(cOrderDate);

		// Create a second formatted column using a PropertyDescriptor.
		// The formatting character "c" specifies a currency format.    
		DataGridColumnStyle csOrderFreight = 
			new DataGridTextBoxColumn(pcol["Freight"], "c", true);
		csOrderFreight.MappingName = "Freight";
		csOrderFreight.HeaderText = "Formatted Freight";
		csOrderFreight.Width = 100;
		ts2.GridColumnStyles.Add(csOrderFreight);

		// Add the DataGridTableStyle instances to 
		// the GridTableStylesCollection
		myDataGrid.TableStyles.Add(ts1);
		myDataGrid.TableStyles.Add(ts2);

		// Sets the TablesAlreadyAdded to true so this doesn't happen again.
		TablesAlreadyAdded = true;
	}

	// Create a DataSet with two tables and populate it.
	private void MakeDataSet()
	{
		// Setup DB-Connection
		string ConnectionString = "data source=xeon;uid=sa;password=manager;database=northwind";
		SqlConnection cn = new SqlConnection(ConnectionString);

		// Create the DataSet
		myDataSet = new DataSet("CustOrders");

		// Fill the Dataset with Customers, map Default Tablename
		// "Table" to "Customers".
		SqlDataAdapter da1 = new SqlDataAdapter("SELECT * FROM Customers",cn);
		da1.TableMappings.Add("Table","Customers");
		da1.Fill(myDataSet);

		// Fill the Dataset with Orders, map Default Tablename
		// "Table" to "Orders".
		SqlDataAdapter da2 = new SqlDataAdapter("SELECT * FROM Orders",cn);
		da2.TableMappings.Add("Table","Orders");
		da2.Fill(myDataSet);
	}

	private void Grid_MouseUp(object sender, MouseEventArgs e)
	{
		// Create a HitTestInfo object using the HitTest method.

		// Get the DataGrid by casting sender.
		DataGrid myGrid = (DataGrid)sender;
		DataGrid.HitTestInfo myHitInfo = myGrid.HitTest(e.X, e.Y);
		Console.WriteLine(myHitInfo);
		Console.WriteLine(myHitInfo.Type);
		Console.WriteLine(myHitInfo.Row);
		Console.WriteLine(myHitInfo.Column);
		// MessageBox.Show("HitTestInfo: " + myHitInfo);
	}
}
